summaryrefslogtreecommitdiff
path: root/fetcher.go
diff options
context:
space:
mode:
Diffstat (limited to 'fetcher.go')
-rw-r--r--fetcher.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/fetcher.go b/fetcher.go
index ead9f5f..1a5801b 100644
--- a/fetcher.go
+++ b/fetcher.go
@@ -26,9 +26,9 @@ package rhimport
func FetchFile(ctx *ImportContext) (err error) {
- // TODO: fetch file from ctx.SourceUri and put it into ctx.Conf.TempDir
+ // TODO: fetch file from ctx.SourceUri and put it into ctx.Config.TempDir
- ctx.SourceFile = ctx.Conf.TempDir + "/source-file.ogg"
+ ctx.SourceFile = ctx.Config.TempDir + "/source-file.ogg"
ctx.DeleteSourceFile = true
return
}